import subprocess
import time
import requests

SERVICE_NAME = "md5_stack_backend"
THRESHOLD_UP = 50  # Si plus de 50 requêtes en 10s, ajouter un réplica
THRESHOLD_DOWN = 10  # Si moins de 10 requêtes en 10s, réduire un réplica
MIN_REPLICAS = 1
MAX_REPLICAS = 10
BACKEND_URL = "http://localhost:5000/request_count"

def get_request_count():
    """Récupère le nombre total de requêtes reçues par le backend (non seulement traitées)"""
    try:
        response = requests.get(BACKEND_URL)
        if response.status_code == 200:
            return response.json()["data"]["request_received_count"]  #  On récupère request_received_count
    except Exception as e:
        print(f"❌ Erreur récupération requêtes : {e}")
    return 0

def get_current_replicas():
    """Récupère le nombre actuel de réplicas"""
    result = subprocess.run(["docker", "service", "ls"], capture_output=True, text=True)
    for line in result.stdout.split("\n"):
        if SERVICE_NAME in line:
            return int(line.split()[3].split("/")[0])  # Extrait le nombre actuel de réplicas
    return MIN_REPLICAS

def scale_service(replicas):
    """Met à jour le nombre de réplicas du service"""
    print(f"⚡ Scaling {SERVICE_NAME} to {replicas} replicas...")
    subprocess.run(["docker", "service", "scale", f"{SERVICE_NAME}={replicas}"])

while True:
    request_count = get_request_count()  #  Utilisation de request_received_count ici
    current_replicas = get_current_replicas()
    
    print(f"🔍 Requêtes reçues : {request_count} | Réplicas actuels: {current_replicas}")

    if request_count > THRESHOLD_UP and current_replicas < MAX_REPLICAS:
        print(f"🔥 Beaucoup de requêtes ({request_count}), augmentation des réplicas...")
        scale_service(current_replicas + 1)
    elif request_count < THRESHOLD_DOWN and current_replicas > MIN_REPLICAS:
        print(f"❄️ Peu de requêtes ({request_count}), réduction des réplicas...")
        scale_service(current_replicas - 1)
    else:
        print("✅ Charge stable, pas de scaling nécessaire.")

    time.sleep(10)  # Vérifie toutes les 10 secondes
